descriptives <- function(i, data, sims, groupName, varName, wave,
	extractor=snaSociomatrixExtraction) {
	thenet <- snaSociomatrixExtraction(i, data, sims, groupName, varName, wave)
	require(sna)
	# Krackhardt hierarchy measures:
	d1  <- connectedness(thenet)[1] 
    d2  <- efficiency(thenet)[1]    
	d3  <- hierarchy(thenet, measure="krackhardt")[1] 
	# for lubness, transposition is required: 
	# arrows are supposed to point "upward"!
    d4  <- lubness(gt(thenet))[1] 
    # Number of strong components:
	d5 <- components(thenet)
	# Size of largest strong component:
	d6 <- max(as.numeric(names(table(component.dist(thenet)$csize))))
	# Diameter
	d7 <- max(geodist(component.largest(symmetrize(thenet),
		connected="weak",result="graph"))$gdist) 
	# 50% quantile of (undirected) path lenghts
	d8 <- median(geodist(thenet)$gdist)	
 	# transitivity coefficient
	a <- as.matrix(thenet)
	a2   <- a %*% a
    diag(a2) <- 0
	d9   <- sum(a2*a)/sum(a2)
	return(c(d1,d2,d3,d4,d5,d6,d7,d8,d9))
}

descriptives.keys = c("conn","effi","hier","lub","ncomp","csize",
	"cdiam","medgeo","trans")